# Synchronous Client

::: bookwyrm.BookWyrmClient
options:
members:
\- __init__
\- get_citations
\- stream_citations
\- summarize
\- stream_summarize
\- process_text
\- classify
\- extract_pdf
\- stream_extract_pdf
\- close
\- __enter__
\- __exit__
show_root_heading: true
show_source: true
